"""Django app configuration."""
from django.apps import AppConfig


class DjangoPainConfig(AppConfig):
    """Configuration of django_pain app."""

    name = 'django_pain'
    verbose_name = 'Django Payments and Invoices'
